/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo;

/**
 * Contains various namespaces which are used to designate objects in the global
 * {@link com.silverwrist.dynamo.iface.ObjectProvider ObjectProvider} and other contexts.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface Namespaces
{
  /**
   * Namespace used for objects provided by the application substrate object.
   */
  public static final String SUBSTRATE_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2002/11/29/substrate.objects";

  /**
   * Namespace used to retrieve servlet initialization parameters.
   */
  public static final String SERVLET_INIT_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2002/12/22/servlet.init.params";

  /**
   * Namespace used to retrieve servlet context initialization parameters.
   */
  public static final String SERVLET_CONTEXT_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2002/12/22/servlet.context.params";

  /**
   * Namespace under which the database connections are stored.
   */
  public static final String DATABASE_CONNECTIONS_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2002/12/08/database.connections";

  /**
   * Namespace under which the Dynamo objects are stored.
   */
  public static final String DYNAMO_OBJECT_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2002/12/07/dynamo.objects";

  /**
   * Namespace under which the Dynamo application-level objects are stored.
   */
  public static final String DYNAMO_APPLICATION_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2002/12/08/dynamo.application";

  /**
   * Namespace used to retrieve user information for mail messages.
   */
  public static final String DYNAMO_USER_INFO_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2002/12/13/user.information";

  /**
   * Namespace used to designate group permissions.
   */
  public static final String GROUP_PERMISSIONS_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2002/12/27/group.permissions";

  /**
   * Namespace for the base set of HTML Checker properties.
   */
  public static final String HTMLCHECKER_PROPERTIES_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2003/06/05/htmlchecker.properties";

  /**
   * Namespace for the spelling checker properties.
   */
  public static final String SPELLCHECKER_PROPERTIES_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2003/06/07/spellchecker.properties";

  /**
   * Namespace for the permissions for the Universal Message Store (UniStore).
   */
  public static final String UNISTORE_PERMISSIONS_NAMESPACE =
      "http://www.silverwrist.com/NS/dynamo/2003/06/10/unistore.permissions";

} // end interface Namespaces
