/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.db;

import java.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

abstract class UserManagerOps extends OpsBase
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  static final String HMKEY_UID = "uid";
  static final String HMKEY_USERNAME = "username";
  static final String HMKEY_EMAIL = "email";
  static final String HMKEY_LOCKED = "locked";
  static final String HMKEY_NOSPAM = "nospam";
  static final String HMKEY_CREATED = "created";
  static final String HMKEY_LAST_ACCESS = "last_accessed";

  static final String HMKEY_GID = "gid";
  static final String HMKEY_GROUPNAME = "groupname";
  static final String HMKEY_GACLID = "gaclid";

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected UserManagerOps(DBConnectionPool pool)
  {
    super(pool);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class OpsBase
   *--------------------------------------------------------------------------------
   */

  public void dispose()
  {
    super.dispose();

  } // end dispose

  /*--------------------------------------------------------------------------------
   * Abstract operations
   *--------------------------------------------------------------------------------
   */

  abstract UserObjectOps getObjectOps();

  abstract GroupObjectOps getGroupOps();

  abstract Map getAnonymousUserData() throws DatabaseException;

  abstract Map getUserData(int id) throws DatabaseException;

  abstract Map getUserData(String username) throws DatabaseException;

  abstract Map createNewUser(String username, String email) throws DatabaseException;

  abstract Map getGroupData(int id) throws DatabaseException;

  abstract Map getGroupData(String groupname) throws DatabaseException;

  abstract Map createNewGroup(String groupname) throws DatabaseException;

  abstract void loadUserDefaults(int uid, int[] nsids) throws DatabaseException;

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  static UserManagerOps get(DBConnectionPool pool) throws ConfigException
  {
    return (UserManagerOps)get(pool,UserManagerOps.class.getClassLoader(),
			       UserManagerOps.class.getName() + "_","UserManagerOps");

  } // end get

} // end class UserManagerOps
