/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

/**
 * An extension of {@link com.silverwrist.dynamo.iface.AuditRecord AuditRecord} used for audit records that are
 * being composed and written into the database.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface AuditRecordCompose extends AuditRecord
{
  /**
   * Sets a property on an audit record.  A property is like an "argument" to the audit record,
   * and may be of any type that can be serialized by the Dynamo PropertySerializer.
   *
   * @param index Index of the property to set (0-based).  Up to 8 properties are supported.
   * @param value Value of the property to be set.
   */
  public void setProperty(int index, Object value);

  /**
   * Writes this audit record to the database.
   */
  public void write();
  
} // end interface AuditRecordCompose
