/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

/**
 * An interface that is implemented by components that need to be "shut down" in some manner at
 * a later time.  Commonly implemented by services that need to be shut down when the application
 * is shut down.  Also implemented as the return value for "installation" methods, so that later
 * the installation can be reversed by calling the <CODE>shutdown()</CODE> method, thus eliminating
 * the need fo a separate "uninstallation" method.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface ComponentShutdown
{
  /**
   * Shuts down the component associated with this interface, in a component-specific manner.
   */
  public void shutdown();

} // end interface ComponentShutdown
