/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

import java.io.InputStream;
import java.io.IOException;
import java.security.acl.AclNotFoundException;
import java.util.Date;
import java.util.List;
import com.silverwrist.dynamo.except.DatabaseException;
import com.silverwrist.dynamo.except.DynamoSecurityException;

public interface UniStoreMessage extends SecureObjectStore
{
  public long getMessageID();

  public long getParentMessageID();

  public void setParentMessageID(DynamoUser caller, long id) throws DatabaseException, DynamoSecurityException;

  public int getSequence();

  public void setSequence(DynamoUser caller, int seq) throws DatabaseException, DynamoSecurityException;

  public int getCreatorUID();

  public DynamoUser getCreator() throws DatabaseException;

  public java.util.Date getPostDate();

  public DynamoAcl getAcl() throws DatabaseException, AclNotFoundException;

  public void setAcl(DynamoUser caller, DynamoAcl acl) throws DatabaseException, DynamoSecurityException;

  public int getNumTextParts() throws DatabaseException;

  public int getNumBinaryParts() throws DatabaseException;

  public UniStoreTextPart getTextPart(int index) throws DatabaseException;

  public UniStoreTextPart getTextPart(String namespace, String name) throws DatabaseException;

  public UniStoreBinaryPart getBinaryPart(int index) throws DatabaseException;

  public UniStoreBinaryPart getBinaryPart(String namespace, String name) throws DatabaseException;

  public List getTextParts() throws DatabaseException;

  public List getBinaryParts() throws DatabaseException;

  public UniStoreTextPart createTextPart(DynamoUser caller, String namespace, String name, String mimetype,
					 HTMLChecker data) throws DatabaseException, DynamoSecurityException;

  public UniStoreTextPart createTextPart(DynamoUser caller, String namespace, String name, String mimetype,
					 String data) throws DatabaseException, DynamoSecurityException;

  public UniStoreBinaryPart createBinaryPart(DynamoUser caller, String namespace, String name, DataItem data)
      throws IOException, DatabaseException, DynamoSecurityException;

  public UniStoreBinaryPart createBinaryPart(DynamoUser caller, String namespace, String name, String mimetype,
					     String filename, int length, InputStream data)
      throws DatabaseException, DynamoSecurityException;

  public void delete(DynamoUser caller) throws DatabaseException, DynamoSecurityException;

} // end interface UniStoreMessage
