/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.script;

/**
 * A temporary object used by the {@link com.silverwrist.dynamo.script.ScriptEngine ScriptEngine} to hold
 * a return value from the execution of a script. The <CODE>ScriptEngine</CODE> maintains a stack of these
 * objects to hold return values from nested script levels.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
class ReturnValue
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  Object m_rc = null;     // the return value

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  /**
   * Constructs a new <CODE>ReturnValue</CODE> object.
   */
  public ReturnValue()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  /**
   * Returns the contents of this <CODE>ReturnValue</CODE> object.
   *
   * @return The contents of this <CODE>ReturnValue</CODE> object.
   */
  public Object get()
  {
    return m_rc;

  } // end get

  /**
   * Sets the contents of this <CODE>ReturnValue</CODE> object.
   *
   * @param o The new contents for this <CODE>ReturnValue</CODE> object.
   */
  void set(Object o)
  {
    m_rc = o;

  } // end class 

} // end class ReturnValue
