/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.servlet;

import java.util.*;
import org.apache.commons.lang.enum.*;
import com.silverwrist.dynamo.Verb;

public final class HttpMethod extends Enum
{
  /*--------------------------------------------------------------------------------
   * The actual enumeration values
   *--------------------------------------------------------------------------------
   */

  public static final HttpMethod DELETE  = new HttpMethod("DELETE");   // (standard)
  public static final HttpMethod HEAD    = new HttpMethod("HEAD");     // (standard)
  public static final HttpMethod GET     = new HttpMethod("GET");      // (standard)
  public static final HttpMethod OPTIONS = new HttpMethod("OPTIONS");  // (standard)
  public static final HttpMethod POST    = new HttpMethod("POST");     // (standard)
  public static final HttpMethod PUT     = new HttpMethod("PUT");      // (standard)
  public static final HttpMethod TRACE   = new HttpMethod("TRACE");    // (standard)

  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Map s_verb_map;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  private HttpMethod(String name)
  {
    super(name);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Standard static method implementations
   *--------------------------------------------------------------------------------
   */

  public static HttpMethod getEnum(String name)
  {
    return (HttpMethod)getEnum(HttpMethod.class,name);

  } // end getEnum

  public static Map getEnumMap()
  {
    return getEnumMap(HttpMethod.class);

  } // end getEnumMap

  public static List getEnumList()
  {
    return getEnumList(HttpMethod.class);

  } // end getEnumList

  public static Iterator iterator()
  {
    return iterator(HttpMethod.class);

  } // end iterator

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public Verb toVerb()
  {
    return (Verb)(s_verb_map.get(this));

  } // end toVerb

  /*--------------------------------------------------------------------------------
   * Static initializer
   *--------------------------------------------------------------------------------
   */

  static
  {
    HashMap map = new HashMap();
    map.put(HttpMethod.GET,Verb.GET);
    map.put(HttpMethod.POST,Verb.POST);
    map.put(HttpMethod.PUT,Verb.PUT);
    map.put(HttpMethod.DELETE,Verb.DELETE);
    s_verb_map = Collections.unmodifiableMap(map);

  } // end static initializer

} // end class HttpMethod
