/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.servlet;

import javax.servlet.*;
import com.silverwrist.dynamo.Namespaces;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

class ServletInitObjectProvider extends BaseDelegatingObjectProvider
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private ServletConfig m_config;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  ServletInitObjectProvider(ObjectProvider base, ServletConfig sconf)
  {
    super("ServletInitObjectProvider",base);
    m_config = sconf;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class BaseDelegatingObjectProvider
   *--------------------------------------------------------------------------------
   */

  /**
   * Retrieves an object from this <CODE>ObjectProvider</CODE>.
   *
   * @param namespace The namespace to interpret the name relative to.
   * @param name The name of the object to be retrieved.
   * @return The object reference specified.
   */
  public Object getObject(String namespace, String name)
  {
    if (Namespaces.SERVLET_INIT_NAMESPACE.equals(namespace))
    { // servlet init parameters
      String rc = m_config.getInitParameter(name);
      if (rc==null)
	throw new NoSuchObjectException(getContext(),namespace,name);
      return rc;

    } // end if

    if (Namespaces.SERVLET_CONTEXT_NAMESPACE.equals(namespace))
    { // servlet context parameters
      String rc = m_config.getServletContext().getInitParameter(name);
      if (rc==null)
	throw new NoSuchObjectException(getContext(),namespace,name);
      return rc;

    } // end if
    
    return super.getObject(namespace,name);

  } // end getObject

} // end class ServletInitObjectProvider
