/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.util;

import java.lang.ref.*;

public class IDNameCacheObject extends SoftReference
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private final Integer m_id_key;
  private final DynamoIDKey m_name_key;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public IDNameCacheObject(Integer id_key, DynamoIDKey name_key, Object value)
  {
    super(value);
    m_id_key = id_key;
    m_name_key = name_key;

  } // end constructor

  public IDNameCacheObject(Integer id_key, DynamoIDKey name_key, Object value, ReferenceQueue rq)
  {
    super(value,rq);
    m_id_key = id_key;
    m_name_key = name_key;

  } // end constructor

  public IDNameCacheObject(Integer id_key, String name_key, Object value)
  {
    this(id_key,new DynamoIDKey(name_key),value);

  } // end constructor

  public IDNameCacheObject(Integer id_key, String name_key, Object value, ReferenceQueue rq)
  {
    this(id_key,new DynamoIDKey(name_key),value,rq);

  } // end constructor

  public IDNameCacheObject(int id_key, DynamoIDKey name_key, Object value)
  {
    this(new Integer(id_key),name_key,value);

  } // end constructor

  public IDNameCacheObject(int id_key, DynamoIDKey name_key, Object value, ReferenceQueue rq)
  {
    this(new Integer(id_key),name_key,value,rq);

  } // end constructor

  public IDNameCacheObject(int id_key, String name_key, Object value)
  {
    this(new Integer(id_key),new DynamoIDKey(name_key),value);

  } // end constructor

  public IDNameCacheObject(int id_key, String name_key, Object value, ReferenceQueue rq)
  {
    this(new Integer(id_key),new DynamoIDKey(name_key),value);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final Integer getIDKey()
  {
    return m_id_key;

  } // end getIDKey

  public final DynamoIDKey getNameKey()
  {
    return m_name_key;

  } // end getNameKey

} // end class IDNameCacheObject
