/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.util;

import java.io.IOException;
import com.silverwrist.dynamo.HttpStatusCode;
import com.silverwrist.dynamo.except.RenderingException;
import com.silverwrist.dynamo.iface.*;

/**
 * A Dynamo output object that, when rendered, causes the user's browser to maintain its present content
 * unchanged.  It sends an HTTP status code of 204 (No Content) to the client.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public class NoContent implements SelfRenderable
{
  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  /**
   * Constructs a new <CODE>NoContent</CODE> object.
   */
  public NoContent()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  /**
   * Returns a string representation of the object. In general, the <CODE>toString</CODE> method returns a string
   * that "textually represents" this object. 
   *
   * @return A string representation of the object.
   */
  public String toString()
  {
    return "NoContent";

  } // end toString

  /*--------------------------------------------------------------------------------
   * Implementations from interface SelfRenderable
   *--------------------------------------------------------------------------------
   */

  /**
   * Renders this object to the output.
   *
   * @param control A rendering control object that provides the means to render this object to the output, as
   *                well as providing "output services" (through the
   *                {@link com.silverwrist.dynamo.iface.ServiceProvider ServiceProvider} interface) for the
   *                rendering process to use.
   * @exception java.io.IOException If an I/O error occurs while writing the output.
   * @exception com.silverwrist.dynamo.except.RenderingException If the rendering process fails.
   */
  public void render(SelfRenderControl control) throws IOException, RenderingException
  {
    control.status(HttpStatusCode.S_NODATA);

  } // end render

} // end class NoContent
