/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.velocity;

/**
 * An interface implemented by output objects which may be rendered by the Velocity template engine.
 * These objects supply their own template data, which is loaded into the Velocity engine and executed
 * with the contained parameters.
 * <P>Objects that implement this interface are rendered by the
 * {@link com.silverwrist.dynamo.velocity.VelocityRenderer VelocityRenderer} component.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface VelocityOwnTemplate extends VelocityParamSupplier
{
  /**
   * Returns the MIME type of the output to be rendered.  Usually, this will be "text/html".
   *
   * @return The MIME type of the output.
   */
  public String getMimeType();

  /**
   * Returns the Velocity template data to be rendered.
   *
   * @return The Velocity template data.
   */
  public String getTemplate();

  /**
   * Returns an identifier for the Velocity template, to be used when generating error messages and
   * the like.
   *
   * @return The Velocity template identifier.
   */
  public String getIdentifier();

} // end interface VelocityOwnTemplate
