/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.testmod;

import java.io.*;
import java.util.*;
import org.apache.log4j.Logger;
import com.silverwrist.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

class TestMod1DObject implements DynamicObject
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Logger logger = Logger.getLogger(TestMod1DObject.class);

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private ModuleSite m_site;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  TestMod1DObject(ModuleSite site)
  {
    m_site = site;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface DynamicObject
   *--------------------------------------------------------------------------------
   */

  public Object get(String property_name) throws DynamicObjectException
  {
    if (property_name.equals("message"))
      return "The TestMod1 object was accessed successfully!";
    if (property_name.equals("msg2"))
    { // load the second message
      try
      { // load the resource
	InputStream istm = m_site.getResourceProvider().getResource("/res1.txt");
	Reader rdr = new InputStreamReader(istm);
	return IOUtils.load(rdr);

      } // end try
      catch (IOException e)
      { // punt on exception
	logger.error("IOException getting msg2",e);
	return null;

      } // end catch

    } // end if

    throw new CodeNotFoundException(TestMod1DClass.get(),CodeNotFoundException.GET,property_name);

  } // end get

  public void set(String property_name, Object value) throws DynamicObjectException
  {
    throw new CodeNotFoundException(TestMod1DClass.get(),CodeNotFoundException.SET,property_name);

  } // end set

  public Object call(String method_name, Object[] parameters) throws DynamicObjectException
  {
    throw new CodeNotFoundException(TestMod1DClass.get(),CodeNotFoundException.CALL,method_name);

  } // end call

  public Object call(String method_name, List parameters) throws DynamicObjectException
  {
    throw new CodeNotFoundException(TestMod1DClass.get(),CodeNotFoundException.CALL,method_name);

  } // end call

  public DynamicClass getDClass()
  {
    return TestMod1DClass.get();

  } // end getDClass
  
} // end class TestMod1DObject
