/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.session;

import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

class PasswordRecoveryAuthenticator implements Authenticator
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private VeniceSessionManager m_sm;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  PasswordRecoveryAuthenticator(VeniceSessionManager sm)
  {
    m_sm = sm;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface Authenticator
   *--------------------------------------------------------------------------------
   */

  public boolean authenticate(String stored_data, String input_data) throws AuthenticationException
  {
    if (!(stored_data.equals(input_data)))
      return false;
    try
    { // check the timestamp on the data
      int pos = input_data.indexOf('.');
      if (pos<0)
	return false;
      long timestamp = Long.parseLong(input_data.substring(pos+1));
      if ((System.currentTimeMillis() - timestamp)>m_sm.getPasswordRecoveryTime())
	return false;

    } // end try
    catch (NumberFormatException e)
    { // number parse is wrong
      return false;

    } // end catch

    return true;

  } // end authenticate

  public String processInputData(String input_data) throws AuthenticationException
  {
    return input_data;

  } // end processInputData

} // end class PasswordRecoveryAuthenticator
