/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.session;

import java.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.servlet.ServletBase;
import com.silverwrist.dynamo.util.*;
import com.silverwrist.venice.content.*;

public class PasswordRecoveryServlet extends ServletBase
{
  /*--------------------------------------------------------------------------------
   * Abstract implementations from class ServletBase
   *--------------------------------------------------------------------------------
   */

  protected Object process(Request r, Application app) throws Exception
  {
    // Get the parameters.
    String tmp = r.getExtraPath().substring(1);
    int pos = tmp.indexOf('/');
    if (pos<0)
    { // error!
      ResourceBundle b = ResourceBundle.getBundle("com.silverwrist.venice.session.SessionMessages",
						  Locale.getDefault());
      return new ErrorBox(null,b.getString("pwrec.badformat"));

    } // end if

    Integer uid = null;
    String auth = null;
    try
    { // create user ID and authorization string
      uid = new Integer(tmp.substring(0,pos));
      auth = tmp.substring(pos+1);

    } // end try
    catch (NumberFormatException e)
    { // cannot parse the UID
      ResourceBundle b = ResourceBundle.getBundle("com.silverwrist.venice.session.SessionMessages",
						  Locale.getDefault());
      return new ErrorBox(null,b.getString("pwrec.badformat"));

    } // end catch

    // Call the script that implements this function.
    ScriptExecute exec = (ScriptExecute)(r.queryService(ScriptExecute.class));
    return exec.executeScript(new PasswordRecoveryRequest(r,uid,auth),"/util/password_recovery.js");

  } // end process

} // end class PasswordRecoveryServlet
