/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.sidebox;

import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.iface.*;

class StandardSideboxes implements SideboxTypeFactory
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  static final String NAMESPACE = "http://www.silverwrist.com/NS/venice/2003/06/03/standard.sideboxes";

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  StandardSideboxes()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface SideboxTypeFactory
   *--------------------------------------------------------------------------------
   */

  public SideboxFactory createFactory(String type_namespace, String type_name, String box_namespace, String box_name,
				      ObjectProvider properties) throws DynamoException
  {
    if (!(NAMESPACE.equals(type_namespace)))
    { // wrong sidebox type namespace!
      SideboxException ee = new SideboxException(StandardSideboxes.class,"SideboxMessages","std.badNamespace");
      ee.setParameter(0,type_namespace);
      throw ee;

    } // end if

    // Determine which kind of sidebox factory to create.
    if (type_name.equals("community.list"))
      return new CommunityListSidebox(properties);

    // Cannot find sidebox factory for type: throw an exception.
    SideboxException e = new SideboxException(StandardSideboxes.class,"SideboxMessages","std.badName");
    e.setParameter(0,type_name);
    throw e;

  } // end createFactory

} // end class StandardSideboxes
